/*
 * Copyright(C) OASIS(R) 2009, 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */

package client;

/**
 * The Runtime Bridge interface which must be implemented by the runtime bridge class which
 * connects to a given SCA runtime
 * @author Kelvin Goodson
 *
 */
public interface RuntimeBridge {

	/**
	 * Sets the Test configuration for a particular test run
	 * @param testConfiguration
	 */
//	public void setTestConfiguration(TestConfiguration testConfiguration);

	/**
	 * Deploy a set of Contributions to the SCA runtime and start a named Composite which is
	 * present somewhere in one of the Contributions, which represents the application under 
	 * test in the SCA runtime
	 * 
	 * @param compositeName - the name of the composite to start - the composite named in this parameter
	 * must be present in one of the contributions named in the contributionNames parameter.
	 * If the compositeName is null, the SCA runtime can start any composites named as "deployable"
	 * in the sca-contribution.xml file of any of the Contributions.
	 * @param contributionLocation a String containing the location pattern for the contribution(s),
	 * which is a URI containing one or more "%1" substrings where the name of each contribution is
	 * substituted to get the URI of that contribution
	 * @param contributionNames - an array of contribution names as strings
	 * @return true if the contributions were loaded and the composite was started in the SCA runtime, false otherwise
	 */
	boolean startContribution(String compositeName,
			                  String contributionLocation, 
			                  String[] contributionNames) throws Exception;

	/**
	 * Stop the contribution(s)
	 */
	void stopContribution();
	
	/**
	 * Have the runtime bridge check runtime specific exceptions to see
	 * if the exception that was thrown was expected for the specified test. 
	 * How this check is performed is runtime specific
	 *  
	 * @param testName the name of the test being run, e.g. ASM_4001
	 * @param exception the exception object that was caught
	 * @throws Throwable if the exception that was received was not expected or was
	 * the wrong exception
	 */
	public void checkError(String testName, Throwable exception) throws Throwable;	
	
} // end interface RuntimeBridge
